EffectEvent class

What one tick of an effect did; the owner decides how it shows.

Constructors

EffectEvent(String id, double damage, double heal)
A tick of id.
const

Properties

damage → double
Damage dealt.
final
hashCode → int
The hash code for this object.
no setterinherited
heal → double
Health restored.
final
id → String
The effect.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited