NetPeer class

A peer of a NetHost: its number and its connection.

Constructors

NetPeer(int id, NetConnection connection)
Peer id on connection.

Properties

connection → NetConnection
The connection.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The number the host gave it (the host itself is 1; peers start at 2).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(NetMessage message) → void
Sends message to this peer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited