Ore class

An ore of a world.

Constructors

Ore(String block, {required double share, int belowY = 1 << 30})
block in share of the rock's vein cells (0..1) below belowY.
const

Properties

belowY → int
It appears only below this height.
final
block → String
The ore block.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
share → double
Its share of the vein cells, 0..1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited