normal property
The normal of the face the ray entered through, one axis at ±1; zero when the ray starts inside the block.
Implementation
final IVec3 normal;
The normal of the face the ray entered through, one axis at ±1; zero when the ray starts inside the block.
final IVec3 normal;