TreeShape enum

The tree shapes of Trees.

Inheritance
Available extensions

Values

oak → const TreeShape

A trunk, two limbs and a round crown.

bigOak → const TreeShape

A 2 x 2 trunk under a crown five wide.

spruce → const TreeShape

Tiers of leaves on a tall trunk.

willow → const TreeShape

A flat drooping canopy.

jungle → const TreeShape

A 2 x 2 giant with two crowns and vines.

palm → const TreeShape

A leaning trunk under a star of fronds.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TreeShape>
A constant List of the values in this enum, in order of their declaration.