CaveSpec class
The caves of a world.
Constructors
Properties
- enabled → bool
-
Whether caves are carved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lava → String?
-
The deep block, or null for air all the way down.
final
- lavaBelowY → int
-
Lava fills carved cells at or below this height.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited