VoxelModelArrays class
A voxel model's faces as flat arrays, four vertices and six indices a face.
Constructors
- VoxelModelArrays(int faces, Float32List positions, Float32List normals, Float32List colors, Int32List indices)
-
The arrays of
facesquads.const
Properties
- colors → Float32List
-
rgba per vertex: the voxel colour times its face tint, alpha 1.
final
- faces → int
-
How many quads.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indices → Int32List
-
Two triangles per quad.
final
- normals → Float32List
-
xyz per vertex, one axis at ±1.
final
- positions → Float32List
-
xyz per vertex, in metres.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited